function [x,X] = bisect(f, int, tol)
% bisect - bisection algorithm for the scalar equation f(x) = 0
% 
%   Syntax: 
%           [x,X] = bisect(f, int, tol)
%   Arguments: 
%           f - string containing the name of a function file  
%           int - 1x2 matrix specifying an interval int = [a,b]
%           tol - a tolerance 
%   Returns: 
%           x, X - column vectors containing the left and right endpoints 
%           of the bisected intervals
%   Description:
%           The program bisect uses the bisection algorithm to 
%           compute an approximate solution of the scalar equation
%           f(x) = 0 in the interval int = [a,b].  The file f.m must 
%           contain the function y = f(x).  The function values f(a) 
%           and f(b) must have opposite signs. 
%   Examples: 
%          [x,X] = bisect(@sin,[1,4],1e-7)   computes pi to 7 decimals
%
%----------------------------------------------------------------------

Write your program here!   

/stig 
